@@ -35,7 +35,7 @@ impl Element {
 
     /// Return the name.
     #[inline]
-    pub fn get_name(&self) -> &String {
+    pub fn get_name(&self) -> &str {
         &self.name
     }
 
@@ -108,8 +108,147 @@ impl Node for Element {
     {
         self.attributes.insert(name.into(), value.into());
     }
+
+    #[inline]
+    fn get_name(&self) -> &str {
+        Self::get_name(self)
+    }
+
+    #[inline]
+    fn get_attributes(&self) -> Option<&Attributes> {
+        Self::get_attributes(self).into()
+    }
+
+    #[inline]
+    fn get_attributes_mut(&mut self) -> Option<&mut Attributes> {
+        Self::get_attributes_mut(self).into()
+    }
+
+    #[inline]
+    fn get_children(&self) -> Option<&Children> {
+        Self::get_children(self).into()
+    }
+
+    #[inline]
+    fn get_children_mut(&mut self) -> Option<&mut Children> {
+        Self::get_children_mut(self).into()
+    }
 }
 
+macro_rules! implement_nested(
+    ($struct_name:ident::$field_name:ident) => (
+        implement_nested!($struct_name::$field_name []);
+    );
+    ($struct_name:ident::$field_name:ident [$($indicator_name:ident),*]) => (
+        impl $struct_name {
+            /// Append a node.
+            pub fn add<T>(mut self, node: T) -> Self
+            where
+                T: Into<Box<dyn Node>>,
+            {
+                Node::append(&mut self, node);
+                self
+            }
+
+            /// Assign an attribute.
+            #[inline]
+            pub fn set<T, U>(mut self, name: T, value: U) -> Self
+            where
+                T: Into<String>,
+                U: Into<Value>,
+            {
+                Node::assign(&mut self, name, value);
+                self
+            }
+        }
+
+        impl Node for $struct_name {
+            #[inline]
+            fn append<T>(&mut self, node: T)
+            where
+                T: Into<Box<dyn Node>>,
+            {
+                self.$field_name.append(node);
+            }
+
+            #[inline]
+            fn assign<T, U>(&mut self, name: T, value: U)
+            where
+                T: Into<String>,
+                U: Into<Value>,
+            {
+                self.$field_name.assign(name, value);
+            }
+
+            #[inline]
+            fn get_name(&self) -> &str {
+                self.$field_name.get_name()
+            }
+
+            #[inline]
+            fn get_attributes(&self) -> Option<&Attributes> {
+                self.$field_name.get_attributes().into()
+            }
+
+            #[inline]
+            fn get_attributes_mut(&mut self) -> Option<&mut Attributes> {
+                self.$field_name.get_attributes_mut().into()
+            }
+
+            #[inline]
+            fn get_children(&self) -> Option<&Children> {
+                self.$field_name.get_children().into()
+            }
+
+            #[inline]
+            fn get_children_mut(&mut self) -> Option<&mut Children> {
+                self.$field_name.get_children_mut().into()
+            }
+
+            $(
+                #[inline]
+                fn $indicator_name(&self) -> bool {
+                    true
+                }
+            )*
+        }
+
+        impl std::ops::Deref for $struct_name {
+            type Target = Element;
+
+            #[inline]
+            fn deref(&self) -> &Self::Target {
+                &self.$field_name
+            }
+        }
+
+        impl std::ops::DerefMut for $struct_name {
+            #[inline]
+            fn deref_mut(&mut self) -> &mut Self::Target {
+                &mut self.$field_name
+            }
+        }
+
+        impl std::fmt::Display for $struct_name {
+            #[inline]
+            fn fmt(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                if self.is_bareable() {
+                    write!(formatter, "{:#}", self.$field_name)
+                } else {
+                    self.$field_name.fmt(formatter)
+                }
+            }
+        }
+
+        impl From<$struct_name> for Element {
+            #[inline]
+            fn from(value: $struct_name) -> Self {
+                value.$field_name
+            }
+        }
+    );
+);
+
 macro_rules! implement {
     ($(#[$doc:meta] struct $struct_name:ident)*) => ($(
         #[$doc]
@@ -141,7 +280,7 @@ macro_rules! implement {
             }
         }
 
-        node! { $struct_name::inner }
+        implement_nested! { $struct_name::inner }
     )*);
 }
 
@@ -361,7 +500,7 @@ macro_rules! implement {
             }
         }
 
-        node! { $struct_name::inner [$($indicator_name),*] }
+        implement_nested! { $struct_name::inner [$($indicator_name),*] }
     )*);
 }
 
@@ -411,7 +550,7 @@ fn escape(value: &str) -> String {
 #[cfg(test)]
 mod tests {
     use super::{Element, Rectangle, Style, Title};
-    use crate::node::{element, Node};
+    use crate::node::element;
 
     #[test]
     fn element_children() {
@@ -435,6 +574,8 @@ mod tests {
 
     #[test]
     fn element_display() {
+        use crate::node::Node;
+
         let mut element = Element::new("foo");
         element.assign("x", -10);
         element.assign("y", "10px");
@@ -474,6 +615,8 @@ mod tests {
 
     #[test]
     fn element_display_quotes() {
+        use crate::node::Node;
+
         let mut element = Element::new("foo");
         element.assign("s", "'single'");
         element.assign("d", r#""double""#);
