@@ -32,6 +32,7 @@ pub mod traits {
 	pub use super::iadvisesink::ole_IAdviseSink;
 	pub use super::ibindctx::ole_IBindCtx;
 	pub use super::idataobject::ole_IDataObject;
+	pub use super::idroptarget::ole_IDropTarget;
 	pub use super::imoniker::ole_IMoniker;
 	pub use super::ipersist::ole_IPersist;
 	pub use super::ipersistfile::ole_IPersistFile;
@@ -42,3 +43,19 @@ pub mod traits {
 	pub use super::istream::ole_IStream;
 	pub use super::iunknown::ole_IUnknown;
 }
+
+pub mod vt {
+	pub use super::iadvisesink::IAdviseSinkVT;
+	pub use super::ibindctx::IBindCtxVT;
+	pub use super::idataobject::IDataObjectVT;
+	pub use super::idroptarget::IDropTargetVT;
+	pub use super::imoniker::IMonikerVT;
+	pub use super::ipersist::IPersistVT;
+	pub use super::ipersistfile::IPersistFileVT;
+	pub use super::ipersiststream::IPersistStreamVT;
+	pub use super::ipicture::IPictureVT;
+	pub use super::isequentialstream::ISequentialStreamVT;
+	pub use super::istorage::IStorageVT;
+	pub use super::istream::IStreamVT;
+	pub use super::iunknown::IUnknownVT;
+}
